Contributors
------------

The ``django-twilio`` library is the result of effort given by the following
awesome Twilio / Django / Python community members:

* `Randall Degges <https://github.com/rdegges>`_ - original author
* `Jason Held <https://github.com/jheld>`_ - current maintainer
* `Paul Hallett <https://github.com/phalt>`_ - past maintainer
* `Lee Trout <https://github.com/leetrout>`_
* `Roger Boardman <https://github.com/boardman>`_
* `Kyle Conroy <https://github.com/kyleconroy>`_
* `Justin Van Koten <https://github.com/jvankoten>`_
* `Issac Kelly <https://github.com/issackelly>`_
* `Zopsi <https://github.com/zopsi>`_
* `Suloev Dmitry <https://github.com/ComradeDOS>`_
* `Matt Carpenter <https://github.com/mattcarp>`_
* `Scott Clark <https://github.com/clarkbarz>`_
* `Felix Schwarz <https://github.com/FelixSchwarz>`_
* `Florian Le Goff <https://github.com/madflo>`_
* `Richard Kolkovich <https://github.com/sarumont>`_
* `Sunah Suh <https://github.com/sunahsuh>`_
* `Daniel Hawkins <https://github.com/hwkns>`_
* `wbt <https://github.com/wbt>`_
* `shinriyo <https://github.com/shinriyo>`_
* `Mathieu Steele <https://github.com/mathieusteele>`_
* `Sarah Bird <https://github.com/birdsarah>`_

Without their support, we wouldn't have such a well-written library.
Thanks folks!
